about summary refs log tree commit diff stats
path: root/WWW/Library/Implementation/HTAccess.c
diff options
context:
space:
mode:
Diffstat (limited to 'WWW/Library/Implementation/HTAccess.c')
-rw-r--r--WWW/Library/Implementation/HTAccess.c11
1 files changed, 8 insertions, 3 deletions
diff --git a/WWW/Library/Implementation/HTAccess.c b/WWW/Library/Implementation/HTAccess.c
index ba73c3fe..c2e75d41 100644
--- a/WWW/Library/Implementation/HTAccess.c
+++ b/WWW/Library/Implementation/HTAccess.c
@@ -843,17 +843,22 @@ PRIVATE BOOL HTLoadDocument ARGS4(
 	    reloading = TRUE;
 #endif
 	    ForcingNoCache = YES;
-            if (TRACE)
+            if (TRACE) {
 	        fprintf(stderr, "HTAccess: Auto-reloading document.\n");
+	    }
 	}
     }
 
     /*
     **  Get the document from the net.  If we are auto-reloading,
     **  the previous rendition will be freed in conjunction with
     **  loading of the new rendition. - FM
     */
     LYforce_no_cache = NO;  /* reset after each time through */
+    if (ForcingNoCache) {
+	FREE(anchor->title);
+    }
     status = HTLoad(address_to_load, anchor, format_out, sink);
     if (TRACE) {
 	fprintf(stderr, "HTAccess:  status=%d\n", status);
@@ -843,17 +843,22 @@ PRIVATE BOOL HTLoadDocument ARGS4(
     /*
     **  Get the document from the net.  If we are auto-reloading,
-    **  the previous rendition will be freed in conjunction with
-    **  loading of the new rendition. - FM
+    **  the mutable anchor elements from the previous rendition
+    **  should be freed in conjunction with loading of the new
+    **  rendition. - FM
     */
     LYforce_no_cache = NO;  /* reset after each time through */